@@ -2,8 +2,8 @@ package Graphics::Primitive::Driver;
 use Moose::Role;
 
 requires qw(
-    _draw_canvas _draw_component _draw_line _draw_textbox
-    _do_stroke data get_text_bounding_box write
+    _draw_canvas _draw_component _draw_line _draw_path _draw_textbox
+    _do_fill _do_stroke data get_text_bounding_box write
 );
 
 sub data {
@@ -62,6 +62,33 @@ To write a driver for Graphics::Primitive implemeent this role.
     width => 500, height => 350
   });
 
+=head1 CANVASES
+
+When a path is added to the internal list via I<do>, it is stored in the
+I<paths> attribute as a hashref.  The hashref has two keys: B<path> and B<op>.
+The path is, well, the path.  The op is the operation provided to I<do>.  As
+canvases are just lists of paths you should consult the next section as well.
+
+=head1 PATHS AND HINTING
+
+Paths are lists of primitives.  Primitives are all descendants of
+L<Geometry::Shape> and therefore have I<point_start> and I<point_end>.  These
+two attributes allow the chaining of primitives.  To draw a path you should
+iterate over the primitives, drawing each.
+
+When you pull each path from the arrayref you should pull it's accompanying
+hints via I<get_hint> (the indexes match).  The hint may provide you with
+additional information:
+
+=over 4
+
+=item I<contiguous>
+
+True if this primitive is contiguous with the previous one.  Example: Used to
+determine if a new sub-path is needed for the Cairo driver.
+
+=back
+
 =head1 WARNING
 
 Only this class or the driver itself should call methods starting with an
@@ -71,6 +98,14 @@ underscore, as this interface may change.
 
 =over 4
 
+=item I<_do_stroke>
+
+Perform a stroke.
+
+=item I<_do_fill>
+
+Perform a fill.
+
 =item I<_draw_canvas>
 
 Draw a canvas.
@@ -83,14 +118,14 @@ Draw a component.
 
 Draw a line.
 
+=item I<_draw_arc>
+
+Draw an arc.
+
 =item I<_draw_textbox>
 
 Draw a textbox.
 
-=item I<_do_stroke>
-
-Perform a stroke.
-
 =item I<data>
 
 Retrieve the results of this driver's operations.
