@@ -7,7 +7,7 @@ no Moose;
 1;
 =head1 NAME
 
-Grahics::Primitive::Operation
+Grahics::Primitive::Operation - A drawing instruction
 
 =head1 DESCRIPTION
 
