@@ -3,6 +3,8 @@ use Moose;
 
 extends 'Graphics::Primitive::Component';
 
+with 'MooseX::Clone';
+
 use Graphics::Primitive::Font
 
 has 'font' => (
@@ -47,7 +49,7 @@ __PACKAGE__->meta->make_immutable;
 __END__
 =head1 NAME
 
-Graphics::Primitive::TextBox
+Graphics::Primitive::TextBox - Text component
 
 =head1 DESCRIPTION
 
@@ -66,6 +68,10 @@ Graphics::Primitive::TextBox is a Componet with text.
       text => 'I am a textbox!'
   );
 
+=head1 WARNING
+
+This component is likely to change drastically.  Here be dragons.
+
 =head1 METHODS
 
 =head2 Constructor
